# SAS-tools – FAIR tools for small-angle scattering data

Welcome to the SAS-tools repository! We develop FAIR, scalable, and sustainable tools for use in analyzing and managing small-angle X-ray scattering (SAXS) data, small-angle neutron scattering (SANS) data, and more.

## 🛠️ What is SAS-tools?

SAS-tools contains useful functions and classes for reading, transforming, working with, analyzing, managing, and storing SAS data (called **tools**). These tools are generic, making it easy to use and re-purpose them. Published workflows using SAS-tools can be found in the [SAS-workflows](https://github.com/FAIRChemistry/SAS-workflows) repository, which can serve as examples and inspiration.

## ⚡️ Quick Start

Get started with SAS-tools by installing the package from PyPI:

```bash
python -m pip install SAS-tools
```

Alternatively, build SAS-tools from source:

```bash
git clone https://github.com/FAIRChemistry/SAS-tools/
cd SAS-tools
python setup.py install
```

## 🔖 Example Code

*coming soon*

## ⚖️ License

Copyright (c) 2022 FAIR Chemistry

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
